@@ -2,4 +2,4 @@ import aws_policy_generator.auto_shortener
 import aws_policy_generator.args_generator
 import aws_policy_generator.mappings
 import aws_policy_generator.yaml_generator
-import aws_policy_generator.safe_minimizer
+import aws_policy_generator.safe_minimizer  # noqa: F401
