@@ -7,6 +7,7 @@ from aws_policy_generator.yaml_generator import generate_from_yaml
 from aws_policy_generator._internal import argparser
 from aws_iam_utils.combiner import collapse_policy_statements
 
+
 def main(args=None, return_policy=False):
     if args is None:
         args = sys.argv[1:]
@@ -17,7 +18,7 @@ def main(args=None, return_policy=False):
 
     if args_namespace.file:
         for file in args_namespace.file:
-            with open(file, 'r') as f:
+            with open(file, "r") as f:
                 policies.append(generate_from_yaml(f))
 
     policies.append(generate_from_args(args_namespace))
@@ -25,7 +26,12 @@ def main(args=None, return_policy=False):
     policy = collapse_policy_statements(*policies)
 
     if args_namespace.auto_shorten:
-        policy_str = auto_shorten_policy(policy, minimize=args_namespace.minimize, compact=args_namespace.compact, max_length=args_namespace.max_length)
+        policy_str = auto_shorten_policy(
+            policy,
+            minimize=args_namespace.minimize,
+            compact=args_namespace.compact,
+            max_length=args_namespace.max_length,
+        )
     else:
         policy_str = json.dumps(policy, indent=2)
 
